simple-calc-0.1.7 is not a library.
simple-calc
A (not so) simple calculator made in Rust.
This calculator contains the four basic math operations, rounding, other stuff inside advanced mode.
Great if you need a reliable, light calculator to use with assignments or quick calculations.
(P.S. don't use this for solving something as hard as the Riemann Hypothesis.)
Note from creator
I don't think simple-calc is so simple anymore...
Dependencies
- clearscreen (4.0.6)
- colored (3.1.1)
- inquire (0.9.4)
Usage
Just run simple-calc, easy as that.
License
Licensed under MIT License.