simple-calc 0.1.1

A simple, very overengineered calculator made in Rust.
simple-calc-0.1.1 is not a library.

simple-calc

A simple, very overengineered calculator made in Rust.

This calculator is really simple, it just contains the four basic math operations, so don't expect too much of it.

Great if you need a quick calculator on the fly, otherwise don't use this.

Dependencies

  • colored (3.1.1)
  • inquire (0.9.4)

Usage

Just run simple-calc, easy as that.

License

Licensed under MIT License.